#
# spec file for package translator
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.rapidfingers.translator
Name:           translator
Version:        1.4.1
Release:        2.4
Summary:        Translation program
License:        GPL-3.0-or-later
URL:            https://github.com/RapidFingers/Translator
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)

%description
This is a translator. It is suited only for small messages, not
big text. Google Translate is used as the backend.

%lang_package

%prep
%autosetup -n Translator-%{version}

cp debian/copyright COPYING

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove recommending lang package
  * remove HiDPI workaround
* Mon Apr  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.1:
  * Translations to brazilian portuguese (thanks to korndorfer)
  * Fix appdata translations (thanks to NathanBnm)
  * Save theme settings (thanks to camellan)
  * Fix dark theme color
* Mon Mar 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.0:
  * Clear button (thanks to camellan)
  * Copy button (thanks to camellan)
  * More languages and translations (thanks to camellan)
  * Bug fixes (thanks to camellan)
* Mon Jan 28 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.2:
  * Switch to meson
- Add HiDPI icons
- Remove obsolete macros
- Spec file cleanup
* Sat Apr  7 2018 avvissu@yandex.by
- Update to 1.2.1:
  * Timeout before translate
  * Fix useless translate on language combobox click
  * Fixed lack of translation, when text is changed during the
    transfer
* Sat Mar 17 2018 avvissu@yandex.by
- Update to 1.2.0:
  * Merge pull request #37 from
    mkinitcpio/#35-Ugly_selected_text_highlight
  * Fix #24 Fix #13
  * Remove space
  * Fix text selection style
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.1.0:
  * Removed custom icons
  * Homepage fix
  * Site fix
  * Update README.md
  * Set theme jekyll-theme-cayman
  * Fix app data
  * Fix dark theme
  * Slovak lang; Refactor GlobalSettings
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 1.0.6:
  * Fix AppStream info
  * Fix icon
  * Serbian language; Better desktop info
  * Merge pull request #27 from cassidyjames/patch-1
  * Merge pull request #25 from rankovic/master
- Add README.md
* Tue Dec 26 2017 jengelh@inai.de
- Compact filler wording from description.
* Fri Nov 10 2017 avvissu@yandex.by
- Update to 1.0.3:
  * New language select
  * More languages
  * Fix control file
- Switch from bzr to git
- Add COPYING and AppData files
- Spec file cleanup
* Fri Mar  4 2016 and.november@opensuse.org
- initial package (version 0.7) for openSUSE
